@@ -3,4 +3,7 @@ from django.db import connections
 from django.db.utils import DEFAULT_DB_ALIAS
 
 
-gis_backend = '.gis.' in connections[DEFAULT_DB_ALIAS].__module__
+gis_backend = any((
+    '.gis.' in connections[DEFAULT_DB_ALIAS].__module__,
+    '.dummy.' in connections[DEFAULT_DB_ALIAS].__module__,
+))
